diff rvinterf/libg23/fmtfunc.c @ 627:42c91c51ca7f

rvinterf: display GPF packets as "GPF" rather than "G23"
author Michael Spacefalcon <msokolov@ivan.Harhan.ORG>
date Mon, 01 Sep 2014 06:23:38 +0000
parents 91ea7a4a0b4d
children
line wrap: on
line diff
--- a/rvinterf/libg23/fmtfunc.c	Sun Aug 31 05:04:56 2014 +0000
+++ b/rvinterf/libg23/fmtfunc.c	Mon Sep 01 06:23:38 2014 +0000
@@ -1,9 +1,9 @@
 /*
  * This libg23 module exports functions for formatting 3 different kinds
  * of G23 packets into human-readable form: traces, system primitives
  * and protocol stack primitives.
  *
  * G23 packets passed to these functions to decoding MUST have already
  * been verified to be well-formed for their respective type.
  */
 
@@ -52,7 +52,7 @@
 	u_char *rxpkt;
 	char **outp, *typestr;
 {
-	sprintf(*outp, "G23 %s id=%02X ts=%02X%02X%02X%02X ", typestr,
+	sprintf(*outp, "GPF %s id=%02X ts=%02X%02X%02X%02X ", typestr,
 		rxpkt[1], rxpkt[7], rxpkt[6], rxpkt[5], rxpkt[4]);
 	*outp = index(*outp, '\0');
 	print_entity_name(rxpkt + 8, outp);
@@ -1,9 +1,9 @@
 /*
  * This libg23 module exports functions for formatting 3 different kinds
- * of G23 packets into human-readable form: traces, system primitives
+ * of GPF packets into human-readable form: traces, system primitives
  * and protocol stack primitives.
  *
@@ -1,9 +1,9 @@
  * and protocol stack primitives.
  *
- * G23 packets passed to these functions to decoding MUST have already
+ * GPF packets passed to these functions for decoding MUST have already
  * been verified to be well-formed for their respective type.
  */